# Class: Certificate

An X509 certificate used for TLS connections

## Fields for class: Certificate

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`fingerprint`       |`string`            |_RO/constructor_|**Deprecated.** Use fingerprint&#95;sha256 instead      |
|`fingerprint_sha1`  |`string`            |_RO/constructor_|The certificate's SHA1 fingerprint / hash|
|`fingerprint_sha256`|`string`            |_RO/constructor_|The certificate's SHA256 fingerprint / hash|
|`host`              |`host ref`          |_RO/constructor_|The host where the certificate is installed|
|`name`              |`string`            |_RO/runtime_   |The name of the certificate, only present on certificates of type 'ca'|
|`not_after`         |`datetime`          |_RO/constructor_|Date before which the certificate is valid|
|`not_before`        |`datetime`          |_RO/constructor_|Date after which the certificate is valid|
|`type`              |`certificate_type`  |_RO/runtime_   |The type of the certificate, either 'ca', 'host' or 'host&#95;internal'|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: Certificate

### RPC name: get&#95;all

_Overview:_

Return a list of all the Certificates known to the system.

_Signature:_

```
Certificate ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `Certificate ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Certificate references to Certificate records for all Certificates known to the system.

_Signature:_

```
(Certificate ref -> Certificate record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(Certificate ref -> Certificate record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Certificate instance with the specified UUID.

_Signature:_

```
Certificate ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Certificate ref`

reference to the object

### RPC name: get&#95;fingerprint

**This message is deprecated.**

_Overview:_

Get the fingerprint field of the given Certificate.

_Signature:_

```
string get_fingerprint (session ref session_ref, Certificate ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Certificate ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;fingerprint&#95;sha1

_Overview:_

Get the fingerprint&#95;sha1 field of the given Certificate.

_Signature:_

```
string get_fingerprint_sha1 (session ref session_ref, Certificate ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Certificate ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;fingerprint&#95;sha256

_Overview:_

Get the fingerprint&#95;sha256 field of the given Certificate.

_Signature:_

```
string get_fingerprint_sha256 (session ref session_ref, Certificate ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Certificate ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;host

_Overview:_

Get the host field of the given Certificate.

_Signature:_

```
host ref get_host (session ref session_ref, Certificate ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Certificate ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;name

_Overview:_

Get the name field of the given Certificate.

_Signature:_

```
string get_name (session ref session_ref, Certificate ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Certificate ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;not&#95;after

_Overview:_

Get the not&#95;after field of the given Certificate.

_Signature:_

```
datetime get_not_after (session ref session_ref, Certificate ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Certificate ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;not&#95;before

_Overview:_

Get the not&#95;before field of the given Certificate.

_Signature:_

```
datetime get_not_before (session ref session_ref, Certificate ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Certificate ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Certificate.

_Signature:_

```
Certificate record get_record (session ref session_ref, Certificate ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Certificate ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Certificate record`

all fields from the object

### RPC name: get&#95;type

_Overview:_

Get the type field of the given Certificate.

_Signature:_

```
certificate_type get_type (session ref session_ref, Certificate ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Certificate ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `certificate_type`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Certificate.

_Signature:_

```
string get_uuid (session ref session_ref, Certificate ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Certificate ref`             |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field
