# Class: pool

Pool&#45;wide information

## Fields for class: pool

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`pool_allowed_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`blobs`             |`(string -> blob ref) map`|_RO/runtime_   |Binary blobs associated with this pool  |
|`client_certificate_auth_enabled`|`bool`              |_RO/runtime_   |True if authentication by TLS client certificates is enabled|
|`client_certificate_auth_name`|`string`            |_RO/runtime_   |The name &#40;CN/SAN&#41; that an incoming client certificate must have to allow authentication|
|`coordinator_bias`  |`bool`              |_RW_           |true if bias against pool master when scheduling vms is enabled, false otherwise|
|`cpu_info`          |`(string -> string) map`|_RO/runtime_   |Details about the physical CPUs on the pool|
|`crash_dump_SR`     |`SR ref`            |_RW_           |The SR in which VDIs for crash dumps are created|
|`current_operations`|`(string -> pool_allowed_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`custom_uefi_certificates`|`string`            |_RO/constructor_|Custom UEFI certificates allowing Secure Boot|
|`default_SR`        |`SR ref`            |_RW_           |Default SR for VDIs                     |
|`ext_auth_cache_enabled`|`bool`              |_RO/runtime_   |Specifies whether external authentication caching is enabled for this pool or not|
|`ext_auth_cache_expiry`|`int`               |_RO/runtime_   |Specifies how long external authentication entries should be cached for &#40;seconds&#41;|
|`ext_auth_cache_size`|`int`               |_RO/runtime_   |Maximum capacity of external authentication cache|
|`ext_auth_max_threads`|`int`               |_RO/constructor_|Maximum number of threads to use for external &#40;AD&#41; authentication|
|`guest_agent_config`|`(string -> string) map`|_RO/runtime_   |Pool&#45;wide guest agent configuration information|
|`gui_config`        |`(string -> string) map`|_RW_           |gui&#45;specific configuration for pool |
|`ha_allow_overcommit`|`bool`              |_RW_           |If set to false then operations which would cause the Pool to become overcommitted will be blocked.|
|`ha_cluster_stack`  |`string`            |_RO/runtime_   |The HA cluster stack that is currently in use. Only valid when HA is enabled.|
|`ha_configuration`  |`(string -> string) map`|_RO/runtime_   |The current HA configuration            |
|`ha_enabled`        |`bool`              |_RO/runtime_   |true if HA is enabled on the pool, false otherwise|
|`ha_host_failures_to_tolerate`|`int`               |_RO/runtime_   |Number of host failures to tolerate before the Pool is declared to be overcommitted|
|`ha_overcommitted`  |`bool`              |_RO/runtime_   |True if the Pool is considered to be overcommitted i.e. if there exist insufficient physical resources to tolerate the configured number of host failures|
|`ha_plan_exists_for`|`int`               |_RO/runtime_   |Number of future host failures we have managed to find a plan for. Once this reaches zero any future host failures will cause the failure of protected VMs.|
|`ha_statefiles`     |`string set`        |_RO/runtime_   |HA statefile VDIs in use                |
|`health_check_config`|`(string -> string) map`|_RW_           |Configuration for the automatic health check feature|
|`igmp_snooping_enabled`|`bool`              |_RO/runtime_   |true if IGMP snooping is enabled in the pool, false otherwise.|
|`is_psr_pending`    |`bool`              |_RW_           |True if either a PSR is running or we are waiting for a PSR to be re&#45;run|
|`last_update_sync`  |`datetime`          |_RO/runtime_   |time of the last update sychronization  |
|`license_server`    |`(string -> string) map`|_RW_           |Licensing data shared within the whole pool|
|`live_patching_disabled`|`bool`              |_RW_           |The pool&#45;wide flag to show if the live patching feauture is disabled or not.|
|`local_auth_max_threads`|`int`               |_RO/constructor_|Maximum number of threads to use for PAM authentication|
|`master`            |`host ref`          |_RO/runtime_   |The host that is pool master            |
|`metadata_VDIs`     |`VDI ref set`       |_RO/runtime_   |The set of currently known metadata VDIs for this pool|
|`migration_compression`|`bool`              |_RW_           |Default behaviour during migration, True if stream compression should be used|
|`name_description`  |`string`            |_RW_           |Description                             |
|`name_label`        |`string`            |_RW_           |Short name                              |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`policy_no_vendor_device`|`bool`              |_RW_           |**Deprecated.** This field was consulted when VM.create did not specify a value for 'has&#95;vendor&#95;device'; VM.create now uses a simple default and no longer consults this value.|
|`recommendations`   |`(string -> string) map`|_RO/runtime_   |The recommended pool properties for clients to respect for optimal performance. e.g. max&#45;vm&#45;group=5|
|`redo_log_enabled`  |`bool`              |_RO/runtime_   |true a redo&#45;log is to be used other than when HA is enabled, false otherwise|
|`redo_log_vdi`      |`VDI ref`           |_RO/runtime_   |indicates the VDI to use for the redo&#45;log other than when HA is enabled|
|`repositories`      |`Repository ref set`|_RO/runtime_   |The set of currently enabled repositories|
|`repository_proxy_password`|`secret ref`        |_RO/runtime_   |Password for the authentication of the proxy used in syncing with the enabled repositories|
|`repository_proxy_url`|`string`            |_RO/runtime_   |Url of the proxy used in syncing with the enabled repositories|
|`repository_proxy_username`|`string`            |_RO/runtime_   |Username for the authentication of the proxy used in syncing with the enabled repositories|
|`restrictions`      |`(string -> string) map`|_RO/runtime_   |Pool&#45;wide restrictions currently in effect|
|`suspend_image_SR`  |`SR ref`            |_RW_           |The SR in which VDIs for suspend images are created|
|`tags`              |`string set`        |_RW_           |user&#45;specified tags for categorization purposes|
|`telemetry_frequency`|`telemetry_frequency`|_RO/runtime_   |How often the telemetry collection will be carried out|
|`telemetry_next_collection`|`datetime`          |_RO/runtime_   |The earliest timestamp &#40;in UTC&#41; when the next round of telemetry collection can be carried out|
|`telemetry_uuid`    |`secret ref`        |_RO/runtime_   |The UUID of the pool for identification of telemetry data|
|`tls_verification_enabled`|`bool`              |_RO/runtime_   |True iff TLS certificate verification is enabled|
|`uefi_certificates` |`string`            |_RO/constructor_|The UEFI certificates allowing Secure Boot|
|`update_sync_day`   |`int`               |_RO/runtime_   |The day of the week the update synchronizations will be scheduled, based on pool's local timezone. Ignored when update&#95;sync&#95;frequency is daily|
|`update_sync_enabled`|`bool`              |_RO/runtime_   |Whether periodic update synchronization is enabled or not|
|`update_sync_frequency`|`update_sync_frequency`|_RO/runtime_   |The frequency at which updates are synchronized from a remote CDN: daily or weekly.|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`vswitch_controller`|`string`            |_RO/runtime_   |**Deprecated.** address of the vswitch controller       |
|`wlb_enabled`       |`bool`              |_RW_           |true if workload balancing is enabled on the pool, false otherwise|
|`wlb_url`           |`string`            |_RO/runtime_   |Url for the configured workload balancing host|
|`wlb_username`      |`string`            |_RO/runtime_   |Username for accessing the workload balancing host|
|`wlb_verify_cert`   |`bool`              |_RW_           |**Deprecated.** true if communication with the WLB server should enforce TLS certificate verification.|

## RPCs associated with class: pool

### RPC name: add&#95;repository

_Overview:_

Add a repository to the enabled set

_Signature:_

```
void add_repository (session ref session_ref, pool ref self, Repository ref value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`Repository ref`              |`value`                       |The repository to be added to the enabled set|

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given pool.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_ref, pool ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;guest&#95;agent&#95;config

_Overview:_

Add a key&#45;value pair to the pool&#45;wide guest agent configuration

_Signature:_

```
void add_to_guest_agent_config (session ref session_ref, pool ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`string`                      |`key`                         |The key to add                          |
|`string`                      |`value`                       |The value to add                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: add&#95;to&#95;gui&#95;config

_Overview:_

Add the given key&#45;value pair to the gui&#95;config field of the given pool.

_Signature:_

```
void add_to_gui_config (session ref session_ref, pool ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;health&#95;check&#95;config

_Overview:_

Add the given key&#45;value pair to the health&#95;check&#95;config field of the given pool.

_Signature:_

```
void add_to_health_check_config (session ref session_ref, pool ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;license&#95;server

_Overview:_

Add the given key&#45;value pair to the license&#95;server field of the given pool.

_Signature:_

```
void add_to_license_server (session ref session_ref, pool ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given pool.

_Signature:_

```
void add_to_other_config (session ref session_ref, pool ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: apply&#95;edition

_Overview:_

Apply an edition to all hosts in the pool

_Signature:_

```
void apply_edition (session ref session_ref, pool ref self, string edition)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |Reference to the pool                   |
|`string`                      |`edition`                     |The requested edition                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: certificate&#95;install

**This message is deprecated.**

_Overview:_

Install a TLS CA certificate, pool&#45;wide.

_Signature:_

```
void certificate_install (session ref session_ref, string name, string cert)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name`                        |A name to give the certificate          |
|`string`                      |`cert`                        |The certificate in PEM format           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: certificate&#95;list

**This message is deprecated.**

_Overview:_

List the names of all installed TLS CA certificates.

_Signature:_

```
string set certificate_list (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `string set`

All installed certificates

### RPC name: certificate&#95;sync

_Overview:_

Copy the TLS CA certificates and CRLs of the master to all slaves.

_Signature:_

```
void certificate_sync (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: certificate&#95;uninstall

**This message is deprecated.**

_Overview:_

Remove a pool&#45;wide TLS CA certificate.

_Signature:_

```
void certificate_uninstall (session ref session_ref, string name)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name`                        |The certificate name                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: check&#95;update&#95;readiness

_Overview:_

Check if the pool is ready to be updated. If not, report the reasons.

_Signature:_

```
string set set check_update_readiness (session ref session_ref, pool ref self, bool requires_reboot)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`bool`                        |`requires_reboot`             |Assume that the update will require host reboots|

_Minimum Role:_ client-cert

_Return Type:_ `string set set`

A set of error codes with arguments, if the pool is
        not ready to update. An empty list means the pool can be updated.

### RPC name: configure&#95;repository&#95;proxy

_Overview:_

Configure proxy for RPM package repositories.

_Signature:_

```
void configure_repository_proxy (session ref session_ref, pool ref self, string url, string username, string password)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`string`                      |`url`                         |The URL of the proxy server             |
|`string`                      |`username`                    |The username used to authenticate with the proxy server|
|`string`                      |`password`                    |The password used to authenticate with the proxy server|

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: configure&#95;update&#95;sync

_Overview:_

Configure periodic update synchronization to sync updates from a remote CDN

_Signature:_

```
void configure_update_sync (session ref session_ref, pool ref self, update_sync_frequency update_sync_frequency, int update_sync_day)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`update_sync_frequency`       |`update_sync_frequency`       |The frequency at which updates are synchronized from a remote CDN: daily or weekly.|
|`int`                         |`update_sync_day`             |The day of the week the update synchronization will happen, based on pool's local timezone. Valid values are 0 to 6, 0 being Sunday. For 'daily' schedule, the value is ignored.|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create&#95;new&#95;blob

_Overview:_

Create a placeholder for a named binary blob of data that is associated with this pool

_Signature:_

```
blob ref create_new_blob (session ref session_ref, pool ref pool, string name, string mime_type, bool public)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`pool`                        |The pool                                |
|`string`                      |`name`                        |The name associated with the blob       |
|`string`                      |`mime_type`                   |The mime type for the data. Empty string translates to application/octet&#45;stream|
|`bool`                        |`public`                      |True if the blob should be publicly available|

_Minimum Role:_ pool-operator

_Return Type:_ `blob ref`

The reference of the blob, needed for populating its data

### RPC name: create&#95;VLAN

_Overview:_

Create PIFs, mapping a network to the same physical interface/VLAN on each host. This call is deprecated: use Pool.create&#95;VLAN&#95;from&#95;PIF instead.

_Signature:_

```
PIF ref set create_VLAN (session ref session_ref, string device, network ref network, int VLAN)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`device`                      |physical interface on which to create the VLAN interface|
|`network ref`                 |`network`                     |network to which this interface should be connected|
|`int`                         |`VLAN`                        |VLAN tag for the new interface          |

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref set`

The references of the created PIF objects

_Possible Error Codes:_ `VLAN_TAG_INVALID`

### RPC name: create&#95;VLAN&#95;from&#95;PIF

_Overview:_

Create a pool&#45;wide VLAN by taking the PIF.

_Signature:_

```
PIF ref set create_VLAN_from_PIF (session ref session_ref, PIF ref pif, network ref network, int VLAN)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PIF ref`                     |`pif`                         |physical interface on any particular host, that identifies the PIF on which to create the &#40;pool&#45;wide&#41; VLAN interface|
|`network ref`                 |`network`                     |network to which this interface should be connected|
|`int`                         |`VLAN`                        |VLAN tag for the new interface          |

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref set`

The references of the created PIF objects

_Possible Error Codes:_ `VLAN_TAG_INVALID`

### RPC name: crl&#95;install

_Overview:_

Install a TLS CA&#45;issued Certificate Revocation List, pool&#45;wide.

_Signature:_

```
void crl_install (session ref session_ref, string name, string cert)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name`                        |A name to give the CRL                  |
|`string`                      |`cert`                        |The CRL                                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: crl&#95;list

_Overview:_

List the names of all installed TLS CA&#45;issued Certificate Revocation Lists.

_Signature:_

```
string set crl_list (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `string set`

The names of all installed CRLs

### RPC name: crl&#95;uninstall

_Overview:_

Remove a pool&#45;wide TLS CA&#45;issued Certificate Revocation List.

_Signature:_

```
void crl_uninstall (session ref session_ref, string name)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name`                        |The CRL name                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: deconfigure&#95;wlb

_Overview:_

Permanently deconfigures workload balancing monitoring on this pool

_Signature:_

```
void deconfigure_wlb (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: designate&#95;new&#95;master

_Overview:_

Perform an orderly handover of the role of master to the referenced host.

_Signature:_

```
void designate_new_master (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host who should become the new master|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: detect&#95;nonhomogeneous&#95;external&#95;auth

_Overview:_

This call asynchronously detects if the external authentication configuration in any slave is different from that in the master and raises appropriate alerts

_Signature:_

```
void detect_nonhomogeneous_external_auth (session ref session_ref, pool ref pool)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`pool`                        |The pool where to detect non&#45;homogeneous external authentication configuration|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: disable&#95;client&#95;certificate&#95;auth

_Overview:_

Disable client certificate authentication on the pool

_Signature:_

```
void disable_client_certificate_auth (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: disable&#95;external&#95;auth

_Overview:_

This call disables external authentication on all the hosts of the pool

_Signature:_

```
void disable_external_auth (session ref session_ref, pool ref pool, (string -> string) map config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`pool`                        |The pool whose external authentication should be disabled|
|`(string -> string) map`      |`config`                      |Optional parameters as a list of key&#45;values containing the configuration data|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: disable&#95;ha

_Overview:_

Turn off High Availability mode

_Signature:_

```
void disable_ha (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: disable&#95;local&#95;storage&#95;caching

_Overview:_

This call disables pool&#45;wide local storage caching

_Signature:_

```
void disable_local_storage_caching (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |Reference to the pool                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: disable&#95;redo&#95;log

_Overview:_

Disable the redo log if in use, unless HA is enabled.

_Signature:_

```
void disable_redo_log (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: disable&#95;repository&#95;proxy

_Overview:_

Disable the proxy for RPM package repositories.

_Signature:_

```
void disable_repository_proxy (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: disable&#95;ssl&#95;legacy

**This message is deprecated.**

_Overview:_

Sets ssl&#95;legacy false on each host, pool&#45;master last. See Host.ssl&#95;legacy and Host.set&#95;ssl&#95;legacy.

_Signature:_

```
void disable_ssl_legacy (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |&#40;ignored&#41;                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: eject

_Overview:_

Instruct a pool master to eject a host from the pool

_Signature:_

```
void eject (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to eject                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: emergency&#95;reset&#95;master

_Overview:_

Instruct a slave already in a pool that the master has changed

_Signature:_

```
void emergency_reset_master (session ref session_ref, string master_address)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`master_address`              |The hostname of the master              |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: emergency&#95;transition&#95;to&#95;master

_Overview:_

Instruct host that's currently a slave to transition to being master

_Signature:_

```
void emergency_transition_to_master (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: enable&#95;client&#95;certificate&#95;auth

_Overview:_

Enable client certificate authentication on the pool

_Signature:_

```
void enable_client_certificate_auth (session ref session_ref, pool ref self, string name)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`string`                      |`name`                        |The name &#40;CN/SAN&#41; that an incoming client certificate must have to allow authentication|

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: enable&#95;external&#95;auth

_Overview:_

This call enables external authentication on all the hosts of the pool

_Signature:_

```
void enable_external_auth (session ref session_ref, pool ref pool, (string -> string) map config, string service_name, string auth_type)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`pool`                        |The pool whose external authentication should be enabled|
|`(string -> string) map`      |`config`                      |A list of key&#45;values containing the configuration data|
|`string`                      |`service_name`                |The name of the service                 |
|`string`                      |`auth_type`                   |The type of authentication &#40;e.g. AD for Active Directory&#41;|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: enable&#95;ha

_Overview:_

Turn on High Availability mode

_Signature:_

```
void enable_ha (session ref session_ref, SR ref set heartbeat_srs, (string -> string) map configuration)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref set`                  |`heartbeat_srs`               |Set of SRs to use for storage heartbeating|
|`(string -> string) map`      |`configuration`               |Detailed HA configuration to apply      |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: enable&#95;local&#95;storage&#95;caching

_Overview:_

This call attempts to enable pool&#45;wide local storage caching

_Signature:_

```
void enable_local_storage_caching (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |Reference to the pool                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: enable&#95;redo&#95;log

_Overview:_

Enable the redo log on the given SR and start using it, unless HA is enabled.

_Signature:_

```
void enable_redo_log (session ref session_ref, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |SR to hold the redo log.                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: enable&#95;ssl&#95;legacy

**This message is removed.**

_Overview:_

Sets ssl&#95;legacy true on each host, pool&#45;master last. See Host.ssl&#95;legacy and Host.set&#95;ssl&#95;legacy.

_Signature:_

```
void enable_ssl_legacy (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |&#40;ignored&#41;                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: enable&#95;tls&#95;verification

_Overview:_

Enable TLS server certificate verification

_Signature:_

```
void enable_tls_verification (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the pools known to the system.

_Signature:_

```
pool ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `pool ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of pool references to pool records for all pools known to the system.

_Signature:_

```
(pool ref -> pool record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(pool ref -> pool record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given pool.

_Signature:_

```
pool_allowed_operations set get_allowed_operations (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool_allowed_operations set`

value of the field

### RPC name: get&#95;blobs

_Overview:_

Get the blobs field of the given pool.

_Signature:_

```
(string -> blob ref) map get_blobs (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> blob ref) map`

value of the field

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the pool instance with the specified UUID.

_Signature:_

```
pool ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `pool ref`

reference to the object

### RPC name: get&#95;client&#95;certificate&#95;auth&#95;enabled

_Overview:_

Get the client&#95;certificate&#95;auth&#95;enabled field of the given pool.

_Signature:_

```
bool get_client_certificate_auth_enabled (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;client&#95;certificate&#95;auth&#95;name

_Overview:_

Get the client&#95;certificate&#95;auth&#95;name field of the given pool.

_Signature:_

```
string get_client_certificate_auth_name (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;coordinator&#95;bias

_Overview:_

Get the coordinator&#95;bias field of the given pool.

_Signature:_

```
bool get_coordinator_bias (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;cpu&#95;info

_Overview:_

Get the cpu&#95;info field of the given pool.

_Signature:_

```
(string -> string) map get_cpu_info (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;crash&#95;dump&#95;SR

_Overview:_

Get the crash&#95;dump&#95;SR field of the given pool.

_Signature:_

```
SR ref get_crash_dump_SR (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given pool.

_Signature:_

```
(string -> pool_allowed_operations) map get_current_operations (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> pool_allowed_operations) map`

value of the field

### RPC name: get&#95;custom&#95;uefi&#95;certificates

_Overview:_

Get the custom&#95;uefi&#95;certificates field of the given pool.

_Signature:_

```
string get_custom_uefi_certificates (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;default&#95;SR

_Overview:_

Get the default&#95;SR field of the given pool.

_Signature:_

```
SR ref get_default_SR (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

### RPC name: get&#95;ext&#95;auth&#95;cache&#95;enabled

_Overview:_

Get the ext&#95;auth&#95;cache&#95;enabled field of the given pool.

_Signature:_

```
bool get_ext_auth_cache_enabled (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;ext&#95;auth&#95;cache&#95;expiry

_Overview:_

Get the ext&#95;auth&#95;cache&#95;expiry field of the given pool.

_Signature:_

```
int get_ext_auth_cache_expiry (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;ext&#95;auth&#95;cache&#95;size

_Overview:_

Get the ext&#95;auth&#95;cache&#95;size field of the given pool.

_Signature:_

```
int get_ext_auth_cache_size (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;ext&#95;auth&#95;max&#95;threads

_Overview:_

Get the ext&#95;auth&#95;max&#95;threads field of the given pool.

_Signature:_

```
int get_ext_auth_max_threads (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;guest&#95;agent&#95;config

_Overview:_

Get the guest&#95;agent&#95;config field of the given pool.

_Signature:_

```
(string -> string) map get_guest_agent_config (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;guest&#95;secureboot&#95;readiness

_Overview:_

_Signature:_

```
pool_guest_secureboot_readiness get_guest_secureboot_readiness (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |

_Minimum Role:_ pool-operator

_Return Type:_ `pool_guest_secureboot_readiness`

The readiness of the pool

### RPC name: get&#95;gui&#95;config

_Overview:_

Get the gui&#95;config field of the given pool.

_Signature:_

```
(string -> string) map get_gui_config (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;ha&#95;allow&#95;overcommit

_Overview:_

Get the ha&#95;allow&#95;overcommit field of the given pool.

_Signature:_

```
bool get_ha_allow_overcommit (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;ha&#95;cluster&#95;stack

_Overview:_

Get the ha&#95;cluster&#95;stack field of the given pool.

_Signature:_

```
string get_ha_cluster_stack (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;ha&#95;configuration

_Overview:_

Get the ha&#95;configuration field of the given pool.

_Signature:_

```
(string -> string) map get_ha_configuration (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;ha&#95;enabled

_Overview:_

Get the ha&#95;enabled field of the given pool.

_Signature:_

```
bool get_ha_enabled (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;ha&#95;host&#95;failures&#95;to&#95;tolerate

_Overview:_

Get the ha&#95;host&#95;failures&#95;to&#95;tolerate field of the given pool.

_Signature:_

```
int get_ha_host_failures_to_tolerate (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;ha&#95;overcommitted

_Overview:_

Get the ha&#95;overcommitted field of the given pool.

_Signature:_

```
bool get_ha_overcommitted (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;ha&#95;plan&#95;exists&#95;for

_Overview:_

Get the ha&#95;plan&#95;exists&#95;for field of the given pool.

_Signature:_

```
int get_ha_plan_exists_for (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;ha&#95;statefiles

_Overview:_

Get the ha&#95;statefiles field of the given pool.

_Signature:_

```
string set get_ha_statefiles (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;health&#95;check&#95;config

_Overview:_

Get the health&#95;check&#95;config field of the given pool.

_Signature:_

```
(string -> string) map get_health_check_config (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;igmp&#95;snooping&#95;enabled

_Overview:_

Get the igmp&#95;snooping&#95;enabled field of the given pool.

_Signature:_

```
bool get_igmp_snooping_enabled (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;is&#95;psr&#95;pending

_Overview:_

Get the is&#95;psr&#95;pending field of the given pool.

_Signature:_

```
bool get_is_psr_pending (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;last&#95;update&#95;sync

_Overview:_

Get the last&#95;update&#95;sync field of the given pool.

_Signature:_

```
datetime get_last_update_sync (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;license&#95;server

_Overview:_

Get the license&#95;server field of the given pool.

_Signature:_

```
(string -> string) map get_license_server (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;license&#95;state

_Overview:_

This call returns the license state for the pool

_Signature:_

```
(string -> string) map get_license_state (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |Reference to the pool                   |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

The pool's license state

### RPC name: get&#95;live&#95;patching&#95;disabled

_Overview:_

Get the live&#95;patching&#95;disabled field of the given pool.

_Signature:_

```
bool get_live_patching_disabled (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;local&#95;auth&#95;max&#95;threads

_Overview:_

Get the local&#95;auth&#95;max&#95;threads field of the given pool.

_Signature:_

```
int get_local_auth_max_threads (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;master

_Overview:_

Get the master field of the given pool.

_Signature:_

```
host ref get_master (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;metadata&#95;VDIs

_Overview:_

Get the metadata&#95;VDIs field of the given pool.

_Signature:_

```
VDI ref set get_metadata_VDIs (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref set`

value of the field

### RPC name: get&#95;migration&#95;compression

_Overview:_

Get the migration&#95;compression field of the given pool.

_Signature:_

```
bool get_migration_compression (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name&#95;description field of the given pool.

_Signature:_

```
string get_name_description (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name&#95;label field of the given pool.

_Signature:_

```
string get_name_label (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given pool.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;policy&#95;no&#95;vendor&#95;device

**This message is deprecated.**

_Overview:_

Get the policy&#95;no&#95;vendor&#95;device field of the given pool.

_Signature:_

```
bool get_policy_no_vendor_device (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;recommendations

_Overview:_

Get the recommendations field of the given pool.

_Signature:_

```
(string -> string) map get_recommendations (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given pool.

_Signature:_

```
pool record get_record (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool record`

all fields from the object

### RPC name: get&#95;redo&#95;log&#95;enabled

_Overview:_

Get the redo&#95;log&#95;enabled field of the given pool.

_Signature:_

```
bool get_redo_log_enabled (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;redo&#95;log&#95;vdi

_Overview:_

Get the redo&#95;log&#95;vdi field of the given pool.

_Signature:_

```
VDI ref get_redo_log_vdi (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

### RPC name: get&#95;repositories

_Overview:_

Get the repositories field of the given pool.

_Signature:_

```
Repository ref set get_repositories (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Repository ref set`

value of the field

### RPC name: get&#95;repository&#95;proxy&#95;password

_Overview:_

Get the repository&#95;proxy&#95;password field of the given pool.

_Signature:_

```
secret ref get_repository_proxy_password (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `secret ref`

value of the field

### RPC name: get&#95;repository&#95;proxy&#95;url

_Overview:_

Get the repository&#95;proxy&#95;url field of the given pool.

_Signature:_

```
string get_repository_proxy_url (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;repository&#95;proxy&#95;username

_Overview:_

Get the repository&#95;proxy&#95;username field of the given pool.

_Signature:_

```
string get_repository_proxy_username (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;restrictions

_Overview:_

Get the restrictions field of the given pool.

_Signature:_

```
(string -> string) map get_restrictions (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;suspend&#95;image&#95;SR

_Overview:_

Get the suspend&#95;image&#95;SR field of the given pool.

_Signature:_

```
SR ref get_suspend_image_SR (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given pool.

_Signature:_

```
string set get_tags (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;telemetry&#95;frequency

_Overview:_

Get the telemetry&#95;frequency field of the given pool.

_Signature:_

```
telemetry_frequency get_telemetry_frequency (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `telemetry_frequency`

value of the field

### RPC name: get&#95;telemetry&#95;next&#95;collection

_Overview:_

Get the telemetry&#95;next&#95;collection field of the given pool.

_Signature:_

```
datetime get_telemetry_next_collection (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;telemetry&#95;uuid

_Overview:_

Get the telemetry&#95;uuid field of the given pool.

_Signature:_

```
secret ref get_telemetry_uuid (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `secret ref`

value of the field

### RPC name: get&#95;tls&#95;verification&#95;enabled

_Overview:_

Get the tls&#95;verification&#95;enabled field of the given pool.

_Signature:_

```
bool get_tls_verification_enabled (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;uefi&#95;certificates

_Overview:_

Get the uefi&#95;certificates field of the given pool.

_Signature:_

```
string get_uefi_certificates (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;update&#95;sync&#95;day

_Overview:_

Get the update&#95;sync&#95;day field of the given pool.

_Signature:_

```
int get_update_sync_day (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;update&#95;sync&#95;enabled

_Overview:_

Get the update&#95;sync&#95;enabled field of the given pool.

_Signature:_

```
bool get_update_sync_enabled (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;update&#95;sync&#95;frequency

_Overview:_

Get the update&#95;sync&#95;frequency field of the given pool.

_Signature:_

```
update_sync_frequency get_update_sync_frequency (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `update_sync_frequency`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given pool.

_Signature:_

```
string get_uuid (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;vswitch&#95;controller

**This message is deprecated.**

_Overview:_

Get the vswitch&#95;controller field of the given pool.

_Signature:_

```
string get_vswitch_controller (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;wlb&#95;enabled

_Overview:_

Get the wlb&#95;enabled field of the given pool.

_Signature:_

```
bool get_wlb_enabled (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;wlb&#95;url

_Overview:_

Get the wlb&#95;url field of the given pool.

_Signature:_

```
string get_wlb_url (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;wlb&#95;username

_Overview:_

Get the wlb&#95;username field of the given pool.

_Signature:_

```
string get_wlb_username (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;wlb&#95;verify&#95;cert

**This message is deprecated.**

_Overview:_

Get the wlb&#95;verify&#95;cert field of the given pool.

_Signature:_

```
bool get_wlb_verify_cert (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: ha&#95;compute&#95;hypothetical&#95;max&#95;host&#95;failures&#95;to&#95;tolerate

_Overview:_

Returns the maximum number of host failures we could tolerate before we would be unable to restart the provided VMs

_Signature:_

```
int ha_compute_hypothetical_max_host_failures_to_tolerate (session ref session_ref, (VM ref -> string) map configuration)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`(VM ref -> string) map`      |`configuration`               |Map of protected VM reference to restart priority|

_Minimum Role:_ read-only

_Return Type:_ `int`

maximum value for ha&#95;host&#95;failures&#95;to&#95;tolerate given provided configuration

### RPC name: ha&#95;compute&#95;max&#95;host&#95;failures&#95;to&#95;tolerate

_Overview:_

Returns the maximum number of host failures we could tolerate before we would be unable to restart configured VMs

_Signature:_

```
int ha_compute_max_host_failures_to_tolerate (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `int`

maximum value for ha&#95;host&#95;failures&#95;to&#95;tolerate given current configuration

### RPC name: ha&#95;compute&#95;vm&#95;failover&#95;plan

_Overview:_

Return a VM failover plan assuming a given subset of hosts fail

_Signature:_

```
(VM ref -> (string -> string) map) map ha_compute_vm_failover_plan (session ref session_ref, host ref set failed_hosts, VM ref set failed_vms)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref set`                |`failed_hosts`                |The set of hosts to assume have failed  |
|`VM ref set`                  |`failed_vms`                  |The set of VMs to restart               |

_Minimum Role:_ pool-operator

_Return Type:_ `(VM ref -> (string -> string) map) map`

VM failover plan: a map of VM to host to restart the host on

### RPC name: ha&#95;failover&#95;plan&#95;exists

_Overview:_

Returns true if a VM failover plan exists for up to 'n' host failures

_Signature:_

```
bool ha_failover_plan_exists (session ref session_ref, int n)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`int`                         |`n`                           |The number of host failures to plan for |

_Minimum Role:_ pool-operator

_Return Type:_ `bool`

true if a failover plan exists for the supplied number of host failures

### RPC name: ha&#95;prevent&#95;restarts&#95;for

_Overview:_

When this call returns the VM restart logic will not run for the requested number of seconds. If the argument is zero then the restart thread is immediately unblocked

_Signature:_

```
void ha_prevent_restarts_for (session ref session_ref, int seconds)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`int`                         |`seconds`                     |The number of seconds to block the restart thread for|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: has&#95;extension

_Overview:_

Return true if the extension is available on the pool

_Signature:_

```
bool has_extension (session ref session_ref, pool ref self, string name)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`string`                      |`name`                        |The name of the API call                |

_Minimum Role:_ pool-admin

_Return Type:_ `bool`

True if the extension exists, false otherwise

### RPC name: initialize&#95;wlb

_Overview:_

Initializes workload balancing monitoring on this pool with the specified wlb server

_Signature:_

```
void initialize_wlb (session ref session_ref, string wlb_url, string wlb_username, string wlb_password, string xenserver_username, string xenserver_password)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`wlb_url`                     |The ip address and port to use when accessing the wlb server|
|`string`                      |`wlb_username`                |The username used to authenticate with the wlb server|
|`string`                      |`wlb_password`                |The password used to authenticate with the wlb server|
|`string`                      |`xenserver_username`          |The username used by the wlb server to authenticate with the xenserver|
|`string`                      |`xenserver_password`          |The password used by the wlb server to authenticate with the xenserver|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: install&#95;ca&#95;certificate

_Overview:_

Install a TLS CA certificate, pool&#45;wide.

_Signature:_

```
void install_ca_certificate (session ref session_ref, string name, string cert)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name`                        |A name to give the certificate          |
|`string`                      |`cert`                        |The certificate in PEM format           |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: join

_Overview:_

Instruct host to join a new pool

_Signature:_

```
void join (session ref session_ref, string master_address, string master_username, string master_password)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`master_address`              |The hostname of the master of the pool to join|
|`string`                      |`master_username`             |The username of the master &#40;for initial authentication&#41;|
|`string`                      |`master_password`             |The password for the master &#40;for initial authentication&#41;|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `JOINING_HOST_CANNOT_CONTAIN_SHARED_SRS`

### RPC name: join&#95;force

_Overview:_

Instruct host to join a new pool

_Signature:_

```
void join_force (session ref session_ref, string master_address, string master_username, string master_password)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`master_address`              |The hostname of the master of the pool to join|
|`string`                      |`master_username`             |The username of the master &#40;for initial authentication&#41;|
|`string`                      |`master_password`             |The password for the master &#40;for initial authentication&#41;|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: management&#95;reconfigure

_Overview:_

Reconfigure the management network interface for all Hosts in the Pool

_Signature:_

```
void management_reconfigure (session ref session_ref, network ref network)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`network`                     |The network                             |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `HA_IS_ENABLED`, `PIF_NOT_PRESENT`, `CANNOT_PLUG_BOND_SLAVE`, `PIF_INCOMPATIBLE_PRIMARY_ADDRESS_TYPE`, `PIF_HAS_NO_NETWORK_CONFIGURATION`, `PIF_HAS_NO_V6_NETWORK_CONFIGURATION`

### RPC name: recover&#95;slaves

_Overview:_

Instruct a pool master, M, to try and contact its slaves and, if slaves are in emergency mode, reset their master address to M.

_Signature:_

```
host ref set recover_slaves (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `host ref set`

list of hosts whose master address were successfully reset

### RPC name: remove&#95;from&#95;guest&#95;agent&#95;config

_Overview:_

Remove a key&#45;value pair from the pool&#45;wide guest agent configuration

_Signature:_

```
void remove_from_guest_agent_config (session ref session_ref, pool ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`string`                      |`key`                         |The key to remove                       |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;gui&#95;config

_Overview:_

Remove the given key and its corresponding value from the gui&#95;config field of the given pool.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_gui_config (session ref session_ref, pool ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;health&#95;check&#95;config

_Overview:_

Remove the given key and its corresponding value from the health&#95;check&#95;config field of the given pool.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_health_check_config (session ref session_ref, pool ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;license&#95;server

_Overview:_

Remove the given key and its corresponding value from the license&#95;server field of the given pool.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_license_server (session ref session_ref, pool ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given pool.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, pool ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;repository

_Overview:_

Remove a repository from the enabled set

_Signature:_

```
void remove_repository (session ref session_ref, pool ref self, Repository ref value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`Repository ref`              |`value`                       |The repository to be removed            |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given pool.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_ref, pool ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: reset&#95;telemetry&#95;uuid

_Overview:_

Assign a new UUID to telemetry data.

_Signature:_

```
void reset_telemetry_uuid (session ref session_ref, pool ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: retrieve&#95;wlb&#95;configuration

_Overview:_

Retrieves the pool optimization criteria from the workload balancing server

_Signature:_

```
(string -> string) map retrieve_wlb_configuration (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

The configuration used in optimizing this pool

### RPC name: retrieve&#95;wlb&#95;recommendations

_Overview:_

Retrieves vm migrate recommendations for the pool from the workload balancing server

_Signature:_

```
(VM ref -> string set) map retrieve_wlb_recommendations (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VM ref -> string set) map`

The list of vm migration recommendations

### RPC name: rotate&#95;secret

_Overview:_

_Signature:_

```
void rotate_secret (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

_Possible Error Codes:_ `INTERNAL_ERROR`, `HOST_IS_SLAVE`, `CANNOT_CONTACT_HOST`, `HA_IS_ENABLED`, `NOT_SUPPORTED_DURING_UPGRADE`

### RPC name: send&#95;test&#95;post

_Overview:_

Send the given body to the given host and port, using HTTPS, and print the response.  This is used for debugging the SSL layer.

_Signature:_

```
string send_test_post (session ref session_ref, string host, int port, string body)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`host`                        |                                        |
|`int`                         |`port`                        |                                        |
|`string`                      |`body`                        |                                        |

_Minimum Role:_ pool-admin

_Return Type:_ `string`

The response

### RPC name: send&#95;wlb&#95;configuration

_Overview:_

Sets the pool optimization criteria for the workload balancing server

_Signature:_

```
void send_wlb_configuration (session ref session_ref, (string -> string) map config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`(string -> string) map`      |`config`                      |The configuration to use in optimizing this pool|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;coordinator&#95;bias

_Overview:_

Set the coordinator&#95;bias field of the given pool.

_Signature:_

```
void set_coordinator_bias (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;crash&#95;dump&#95;SR

_Overview:_

Set the crash&#95;dump&#95;SR field of the given pool.

_Signature:_

```
void set_crash_dump_SR (session ref session_ref, pool ref self, SR ref value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`SR ref`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;custom&#95;uefi&#95;certificates

_Overview:_

Set custom UEFI certificates for a pool and all its hosts. Need `allow&#45;custom&#45;uefi&#45;certs` set to true in conf. If empty: default back to Pool.uefi&#95;certificates

_Signature:_

```
void set_custom_uefi_certificates (session ref session_ref, pool ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`string`                      |`value`                       |The certificates to apply to the pool and its hosts|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;default&#95;SR

_Overview:_

Set the default&#95;SR field of the given pool.

_Signature:_

```
void set_default_SR (session ref session_ref, pool ref self, SR ref value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`SR ref`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;ext&#95;auth&#95;max&#95;threads

_Overview:_

_Signature:_

```
void set_ext_auth_max_threads (session ref session_ref, pool ref self, int value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`int`                         |`value`                       |The new maximum                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;gui&#95;config

_Overview:_

Set the gui&#95;config field of the given pool.

_Signature:_

```
void set_gui_config (session ref session_ref, pool ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: set&#95;ha&#95;allow&#95;overcommit

_Overview:_

Set the ha&#95;allow&#95;overcommit field of the given pool.

_Signature:_

```
void set_ha_allow_overcommit (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;ha&#95;host&#95;failures&#95;to&#95;tolerate

_Overview:_

Set the maximum number of host failures to consider in the HA VM restart planner

_Signature:_

```
void set_ha_host_failures_to_tolerate (session ref session_ref, pool ref self, int value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`int`                         |`value`                       |New number of host failures to consider |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;health&#95;check&#95;config

_Overview:_

Set the health&#95;check&#95;config field of the given pool.

_Signature:_

```
void set_health_check_config (session ref session_ref, pool ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;https&#95;only

_Overview:_

updates all the host firewalls in the pool to open or close port 80 depending on the value

_Signature:_

```
void set_https_only (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`bool`                        |`value`                       |true &#45; http port 80 will be blocked, false &#45; http port 80 will be open for the hosts in the pool|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;igmp&#95;snooping&#95;enabled

_Overview:_

Enable or disable IGMP Snooping on the pool.

_Signature:_

```
void set_igmp_snooping_enabled (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`bool`                        |`value`                       |Enable or disable IGMP Snooping on the pool|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;is&#95;psr&#95;pending

_Overview:_

Set the is&#95;psr&#95;pending field of the given pool.

_Signature:_

```
void set_is_psr_pending (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;license&#95;server

_Overview:_

Set the license&#95;server field of the given pool.

_Signature:_

```
void set_license_server (session ref session_ref, pool ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;live&#95;patching&#95;disabled

_Overview:_

Set the live&#95;patching&#95;disabled field of the given pool.

_Signature:_

```
void set_live_patching_disabled (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;local&#95;auth&#95;max&#95;threads

_Overview:_

_Signature:_

```
void set_local_auth_max_threads (session ref session_ref, pool ref self, int value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`int`                         |`value`                       |The new maximum                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;migration&#95;compression

_Overview:_

Set the migration&#95;compression field of the given pool.

_Signature:_

```
void set_migration_compression (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name&#95;description field of the given pool.

_Signature:_

```
void set_name_description (session ref session_ref, pool ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name&#95;label field of the given pool.

_Signature:_

```
void set_name_label (session ref session_ref, pool ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given pool.

_Signature:_

```
void set_other_config (session ref session_ref, pool ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;policy&#95;no&#95;vendor&#95;device

**This message is deprecated.**

_Overview:_

Set the policy&#95;no&#95;vendor&#95;device field of the given pool.

_Signature:_

```
void set_policy_no_vendor_device (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;repositories

_Overview:_

Set enabled set of repositories

_Signature:_

```
void set_repositories (session ref session_ref, pool ref self, Repository ref set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`Repository ref set`          |`value`                       |The set of repositories to be enabled   |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: set&#95;suspend&#95;image&#95;SR

_Overview:_

Set the suspend&#95;image&#95;SR field of the given pool.

_Signature:_

```
void set_suspend_image_SR (session ref session_ref, pool ref self, SR ref value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`SR ref`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given pool.

_Signature:_

```
void set_tags (session ref session_ref, pool ref self, string set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`string set`                  |`value`                       |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: set&#95;telemetry&#95;next&#95;collection

_Overview:_

Set the timestamp for the next telemetry data collection.

_Signature:_

```
void set_telemetry_next_collection (session ref session_ref, pool ref self, datetime value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`datetime`                    |`value`                       |The earliest timestamp &#40;in UTC&#41; when the next round of telemetry collection can be carried out.|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;uefi&#95;certificates

**This message is deprecated.**

_Overview:_

Set the UEFI certificates for a pool and all its hosts. Deprecated: use set&#95;custom&#95;uefi&#95;certificates instead

_Signature:_

```
void set_uefi_certificates (session ref session_ref, pool ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`string`                      |`value`                       |The certificates to apply to the pool and its hosts|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;update&#95;sync&#95;enabled

_Overview:_

enable or disable periodic update synchronization depending on the value

_Signature:_

```
void set_update_sync_enabled (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`bool`                        |`value`                       |true &#45; enable periodic update synchronization, false &#45; disable it|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;vswitch&#95;controller

**This message is deprecated.**

_Overview:_

Set the IP address of the vswitch controller.

_Signature:_

```
void set_vswitch_controller (session ref session_ref, string address)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`address`                     |IP address of the vswitch controller.   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;wlb&#95;enabled

_Overview:_

Set the wlb&#95;enabled field of the given pool.

_Signature:_

```
void set_wlb_enabled (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ client-cert

_Return Type:_ `void`

### RPC name: set&#95;wlb&#95;verify&#95;cert

**This message is deprecated.**

_Overview:_

Set the wlb&#95;verify&#95;cert field of the given pool.

_Signature:_

```
void set_wlb_verify_cert (session ref session_ref, pool ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: sync&#95;database

_Overview:_

Forcibly synchronise the database now

_Signature:_

```
void sync_database (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: sync&#95;updates

_Overview:_

Sync with the enabled repository

_Signature:_

```
string sync_updates (session ref session_ref, pool ref self, bool force, string token, string token_id)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |The pool                                |
|`bool`                        |`force`                       |If true local mirroring repo will be removed before syncing|
|`string`                      |`token`                       |The token for repository client authentication|
|`string`                      |`token_id`                    |The ID of the token                     |

_Minimum Role:_ client-cert

_Return Type:_ `string`

The SHA256 hash of updateinfo.xml.gz

### RPC name: test&#95;archive&#95;target

_Overview:_

This call tests if a location is valid

_Signature:_

```
string test_archive_target (session ref session_ref, pool ref self, (string -> string) map config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`pool ref`                    |`self`                        |Reference to the pool                   |
|`(string -> string) map`      |`config`                      |Location config settings to test        |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

An XMLRPC result

### RPC name: uninstall&#95;ca&#95;certificate

_Overview:_

Remove a pool&#45;wide TLS CA certificate.

_Signature:_

```
void uninstall_ca_certificate (session ref session_ref, string name, bool force)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name`                        |The certificate name                    |
|`bool`                        |`force`                       |Remove the DB entry even if the file is non&#45;existent|

_Minimum Role:_ client-cert

_Return Type:_ `void`
