# Class: PUSB

A physical USB device

## Fields for class: PUSB

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`description`       |`string`            |_RO/constructor_|USB device description                  |
|`host`              |`host ref`          |_RO/constructor_|Physical machine that owns the USB device|
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`passthrough_enabled`|`bool`              |_RO/runtime_   |enabled for passthrough                 |
|`path`              |`string`            |_RO/constructor_|port path of USB device                 |
|`product_desc`      |`string`            |_RO/constructor_|product description of the USB device   |
|`product_id`        |`string`            |_RO/constructor_|product id of the USB device            |
|`serial`            |`string`            |_RO/constructor_|serial of the USB device                |
|`speed`             |`float`             |_RO/constructor_|USB device speed                        |
|`USB_group`         |`USB_group ref`     |_RO/constructor_|USB group the PUSB is contained in      |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`vendor_desc`       |`string`            |_RO/constructor_|vendor description of the USB device    |
|`vendor_id`         |`string`            |_RO/constructor_|vendor id of the USB device             |
|`version`           |`string`            |_RO/constructor_|USB device version                      |

## RPCs associated with class: PUSB

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PUSB.

_Signature:_

```
void add_to_other_config (session ref session_ref, PUSB ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the PUSBs known to the system.

_Signature:_

```
PUSB ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `PUSB ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PUSB references to PUSB records for all PUSBs known to the system.

_Signature:_

```
(PUSB ref -> PUSB record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(PUSB ref -> PUSB record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PUSB instance with the specified UUID.

_Signature:_

```
PUSB ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PUSB ref`

reference to the object

### RPC name: get&#95;description

_Overview:_

Get the description field of the given PUSB.

_Signature:_

```
string get_description (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;host

_Overview:_

Get the host field of the given PUSB.

_Signature:_

```
host ref get_host (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PUSB.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;passthrough&#95;enabled

_Overview:_

Get the passthrough&#95;enabled field of the given PUSB.

_Signature:_

```
bool get_passthrough_enabled (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;path

_Overview:_

Get the path field of the given PUSB.

_Signature:_

```
string get_path (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;product&#95;desc

_Overview:_

Get the product&#95;desc field of the given PUSB.

_Signature:_

```
string get_product_desc (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;product&#95;id

_Overview:_

Get the product&#95;id field of the given PUSB.

_Signature:_

```
string get_product_id (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PUSB.

_Signature:_

```
PUSB record get_record (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PUSB record`

all fields from the object

### RPC name: get&#95;serial

_Overview:_

Get the serial field of the given PUSB.

_Signature:_

```
string get_serial (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;speed

_Overview:_

Get the speed field of the given PUSB.

_Signature:_

```
float get_speed (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

### RPC name: get&#95;USB&#95;group

_Overview:_

Get the USB&#95;group field of the given PUSB.

_Signature:_

```
USB_group ref get_USB_group (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `USB_group ref`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PUSB.

_Signature:_

```
string get_uuid (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;vendor&#95;desc

_Overview:_

Get the vendor&#95;desc field of the given PUSB.

_Signature:_

```
string get_vendor_desc (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;vendor&#95;id

_Overview:_

Get the vendor&#95;id field of the given PUSB.

_Signature:_

```
string get_vendor_id (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;version

_Overview:_

Get the version field of the given PUSB.

_Signature:_

```
string get_version (session ref session_ref, PUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PUSB.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, PUSB ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: scan

_Overview:_

_Signature:_

```
void scan (session ref session_ref, host ref host)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host                                |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PUSB.

_Signature:_

```
void set_other_config (session ref session_ref, PUSB ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;passthrough&#95;enabled

_Overview:_

_Signature:_

```
void set_passthrough_enabled (session ref session_ref, PUSB ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PUSB ref`                    |`self`                        |this PUSB                               |
|`bool`                        |`value`                       |passthrough is enabled when true and disabled with false|

_Minimum Role:_ pool-admin

_Return Type:_ `void`
