# Class: SM

A storage manager plugin

## Fields for class: SM

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`capabilities`      |`string set`        |_RO/runtime_   |**Deprecated.** capabilities of the SM plugin           |
|`configuration`     |`(string -> string) map`|_RO/runtime_   |names and descriptions of device config keys|
|`copyright`         |`string`            |_RO/runtime_   |Entity which owns the copyright of this plugin|
|`driver_filename`   |`string`            |_RO/runtime_   |filename of the storage driver          |
|`features`          |`(string -> int) map`|_RO/runtime_   |capabilities of the SM plugin, with capability version numbers|
|`name_description`  |`string`            |_RO/runtime_   |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RO/runtime_   |a human&#45;readable name               |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`required_api_version`|`string`            |_RO/runtime_   |Minimum SM API version required on the server|
|`required_cluster_stack`|`string set`        |_RO/runtime_   |The storage plugin requires that one of these cluster stacks is configured and running.|
|`supported_image_formats`|`string set`        |_RO/runtime_   |Image formats suported by the SR &#40;VHD, RAW, Qcow2, ...&#41;|
|`type`              |`string`            |_RO/runtime_   |SR.type                                 |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`vendor`            |`string`            |_RO/runtime_   |Vendor who created this plugin          |
|`version`           |`string`            |_RO/runtime_   |Version of the plugin                   |

## RPCs associated with class: SM

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given SM.

_Signature:_

```
void add_to_other_config (session ref session_ref, SM ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the SMs known to the system.

_Signature:_

```
SM ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `SM ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of SM references to SM records for all SMs known to the system.

_Signature:_

```
(SM ref -> SM record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(SM ref -> SM record) map`

records of all objects

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the SM instances with the given label.

_Signature:_

```
SM ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `SM ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the SM instance with the specified UUID.

_Signature:_

```
SM ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `SM ref`

reference to the object

### RPC name: get&#95;capabilities

**This message is deprecated.**

_Overview:_

Get the capabilities field of the given SM.

_Signature:_

```
string set get_capabilities (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;configuration

_Overview:_

Get the configuration field of the given SM.

_Signature:_

```
(string -> string) map get_configuration (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;copyright

_Overview:_

Get the copyright field of the given SM.

_Signature:_

```
string get_copyright (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;driver&#95;filename

_Overview:_

Get the driver&#95;filename field of the given SM.

_Signature:_

```
string get_driver_filename (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;features

_Overview:_

Get the features field of the given SM.

_Signature:_

```
(string -> int) map get_features (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> int) map`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given SM.

_Signature:_

```
string get_name_description (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given SM.

_Signature:_

```
string get_name_label (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given SM.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given SM.

_Signature:_

```
SM record get_record (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SM record`

all fields from the object

### RPC name: get&#95;required&#95;api&#95;version

_Overview:_

Get the required&#95;api&#95;version field of the given SM.

_Signature:_

```
string get_required_api_version (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;required&#95;cluster&#95;stack

_Overview:_

Get the required&#95;cluster&#95;stack field of the given SM.

_Signature:_

```
string set get_required_cluster_stack (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;supported&#95;image&#95;formats

_Overview:_

Get the supported&#95;image&#95;formats field of the given SM.

_Signature:_

```
string set get_supported_image_formats (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;type

_Overview:_

Get the type field of the given SM.

_Signature:_

```
string get_type (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given SM.

_Signature:_

```
string get_uuid (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;vendor

_Overview:_

Get the vendor field of the given SM.

_Signature:_

```
string get_vendor (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;version

_Overview:_

Get the version field of the given SM.

_Signature:_

```
string get_version (session ref session_ref, SM ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given SM.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, SM ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given SM.

_Signature:_

```
void set_other_config (session ref session_ref, SM ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SM ref`                      |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
